==> 0.3.24+6.tar.gz: lib/pages/comments/widgets/messages_form.dart <==
import 'dart:async';
import 'package:feed_plugin/models/user_model.dart';
import 'package:feed_plugin/service/http_service.dart';
import 'package:feed_plugin/utilities/colors.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
class MessageForm extends StatefulWidget {
  final int postId;
  final UserModel currentUser;
  final loc;

  const MessageForm({
    required this.postId,
    required this.currentUser,
    required this.loc,
  });

  @override
  _MessageFormState createState() => _MessageFormState();
}

class _MessageFormState extends State<MessageForm> {
  TextEditingController? _textEditingController;

  void _sendMessage() {
    if (_textEditingController!.text.isEmpty) return;

    HttpService("jhgvf").uploadComment(
        userId: this.widget.currentUser.id,
        postId: this.widget.postId,
        comment: _textEditingController!.text);
    setState(() {
      _textEditingController!.text = "";
    });
  }

  @override
  void initState() {
    super.initState();
    _textEditingController = TextEditingController();
  }

  @override
  void dispose() {
    _textEditingController!.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      color: Colors.grey.withAlpha(50),
      child: Padding(
        padding: const EdgeInsets.symmetric(horizontal: 10, vertical: 5),
        child: Row(
          children: <Widget>[
            ClipOval(
              child: Image.network(
                this.widget.currentUser.profileImg!,
                width: ScreenUtil().setWidth(38),
                height: ScreenUtil().setWidth(39),
                fit: BoxFit.cover,
              ),
            ),
            Expanded(
              child: Container(
                padding: const EdgeInsets.symmetric(horizontal: 10),
                decoration: BoxDecoration(
                  borderRadius: BorderRadius.circular(50),
                  color: Colors.white,
                ),
                child: TextField(
                  onSubmitted: (_) {
                    _sendMessage();
                  },
                  controller: _textEditingController,
                  decoration: InputDecoration(
                    hintText: this.widget.loc.translate('Type your comment...'),
                    border: InputBorder.none,
                  ),
                ),
              ),
            ),
            Container(
              child: ClipOval(
                child: Material(
                  color: secondColor,
                  child: InkWell(
                    splashColor: secondColor,
                    child: IconButton(
                      onPressed: _sendMessage,
                      icon: Icon(Icons.send_rounded),
                      color: Colors.white,
                      iconSize: 35,
                    ),
                  ),
                ),
              ),
            ),
          ],
        ),
      ),
    );
  }
}

==> 0.3.25+7.tar.gz: lib/pages/comments/widgets/messages_form.dart <==
import 'dart:async';
import 'package:feed_plugin/models/user_model.dart';
import 'package:feed_plugin/service/http_service.dart';
import 'package:feed_plugin/utilities/colors.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

class MessageForm extends StatefulWidget {
  final int postId;
  final UserModel currentUser;
  final loc;

  const MessageForm({
    required this.postId,
    required this.currentUser,
    required this.loc,
  });

  @override
  _MessageFormState createState() => _MessageFormState();
}

class _MessageFormState extends State<MessageForm> {
  TextEditingController? _textEditingController;

  void _sendMessage() {
    if (_textEditingController!.text.isEmpty) return;

    HttpService().uploadComment(
        userId: this.widget.currentUser.id,
        postId: this.widget.postId,
        comment: _textEditingController!.text);
    setState(() {
      _textEditingController!.text = "";
    });
  }

  @override
  void initState() {
    super.initState();
    _textEditingController = TextEditingController();
  }

  @override
  void dispose() {
    _textEditingController!.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      color: Colors.grey.withAlpha(50),
      child: Padding(
        padding: const EdgeInsets.symmetric(horizontal: 10, vertical: 5),
        child: Row(
          children: <Widget>[
            if (this.widget.currentUser.profileImg != null)
              ClipOval(
                child: Image.network(
                  this.widget.currentUser.profileImg!,
                  width: ScreenUtil().setWidth(38),
                  height: ScreenUtil().setWidth(39),
                  fit: BoxFit.cover,
                ),
              ),
            Expanded(
              child: Container(
                padding: const EdgeInsets.symmetric(horizontal: 10),
                decoration: BoxDecoration(
                  borderRadius: BorderRadius.circular(50),
                  color: Colors.white,
                ),
                child: TextField(
                  onSubmitted: (_) {
                    _sendMessage();
                  },
                  controller: _textEditingController,
                  decoration: InputDecoration(
                    hintText: this.widget.loc.translate('Type your comment...'),
                    border: InputBorder.none,
                  ),
                ),
              ),
            ),
            Container(
              child: ClipOval(
                child: Material(
                  color: secondColor,
                  child: InkWell(
                    splashColor: secondColor,
                    child: IconButton(
                      onPressed: _sendMessage,
                      icon: Icon(Icons.send_rounded),
                      color: Colors.white,
                      iconSize: 35,
                    ),
                  ),
                ),
              ),
            ),
          ],
        ),
      ),
    );
  }
}
